@@ -1,5 +1,5 @@
 FKM.ent <-
-function (X, k, ent, RS, stand, startU, conv, maxit)
+function (X, k, ent, RS, stand, startU, conv, maxit, seed)
 {
 if (missing(X))
 stop("The data set must be given")
@@ -139,8 +139,26 @@ maxit=1e+6
 if (maxit%%ceiling(maxit)>0)
 {
 cat("The maximum number of iterations maxit must be an integer >0: the value ceiling(maxit) will be used ",fill=TRUE)
-maxit=1e+6
+maxit=ceiling(maxit)
 } 
+if (missing(seed))
+set.seed(NULL)
+else
+{
+if (!is.numeric(seed)) 
+{
+cat("The seed value is not numeric: set.seed(NULL) will be used ",fill=TRUE)
+set.seed(NULL)
+}else
+{
+if (seed%%ceiling(seed)>0)
+{
+cat("The seed value must be an integer: set.seed(ceiling(seed)) will be used ",fill=TRUE)
+set.seed(ceiling(seed))
+}else
+set.seed(seed)
+}
+}
 Xraw=X
 rownames(Xraw)=rownames(X)
 colnames(Xraw)=colnames(X)
@@ -160,7 +178,6 @@ if ((rs==1) & (check!=1))
 U=startU
 else
 {
-set.seed(rs)
 U=matrix(runif(n*k,0,1), nrow=n, ncol=k)
 U=U/apply(U,1,sum)
 }
@@ -173,7 +190,10 @@ cputime=system.time(
 while ((sum(abs(U.old-U))>conv) && (iter<maxit))
 {
 iter=iter+1
+#D.old=D
 U.old=U
+#H.old=H
+#F.old=F
 for (c in 1:k) 
 H[c,]=(t(U[,c])%*%X)/sum(U[,c])
 for (i in 1:n) 
@@ -185,6 +205,13 @@ D[i,c]=D[i,c]=sum((X[i,]-H[c,])^2)
 }
 for (i in 1:n)
 {
+if (min(D[i,])==0)
+{
+U[i,]=rep(0,k)
+U[i,which.min(D[i,])]=1
+}
+else
+{
 for (c in 1:k)
 {
 U[i,c]=(exp(-D[i,c]/ent))/sum(exp(-D[i,]/ent))
@@ -195,11 +222,14 @@ U[i,c]=.Machine$double.eps
 }
 }
 }
+}
 })
 func=sum(U*D)+ent*sum(U*log(U));
 cput[rs]=cputime[1]
 value[rs]=func
 it[rs]=iter
+if (is.finite(func))
+{
 if (func<func.opt) 
 { 
 U.opt=U
@@ -208,6 +238,7 @@ F.opt=F
 func.opt=func
 }
 }
+}
 rownames(H.opt)=paste("Clus",1:k,sep=" ")
 colnames(H.opt)=cn
 rownames(U.opt)=rn
